/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <glibmm/i18n.h>
#include <gtkmm/messagedialog.h>
#include <gtkmm/main.h>
#include "GotoDialog.h"

GotoDialog::GotoDialog(std::string *GladeFilename)
{
	try
	{
		std::string gladefile;

		refXml = Gnome::Glade::Xml::create(*GladeFilename, "GotoDialog");
	}
	catch (const Gnome::Glade::XmlError& ex)
	{
		Gtk::MessageDialog *message = new Gtk::MessageDialog(_("Error reading data file: ")+*GladeFilename+"\n"+_("Program cannot continue."),
			false,Gtk::MESSAGE_ERROR,Gtk::BUTTONS_CANCEL,true);
		message->run();
		Gtk::Main::quit();
	}

	refXml->get_widget("GotoDialog",GtkDialog);
	refXml->get_widget("Lattitude",Lattitude);
	refXml->get_widget("Longitude",Longitude);
}

GotoDialog::~GotoDialog() {
	delete GtkDialog;
}

int GotoDialog::Run(double *Lon, double *Lat) {
	int result;
	double NewLon,NewLat;

	result=GtkDialog->run();
	if (result) {
		if (sscanf(Longitude->get_text().c_str(), "%lf", &NewLon)!=1)
			return 0;
		if (sscanf(Lattitude->get_text().c_str(), "%lf", &NewLat)!=1)
			return 0;
		*Lon=NewLon;
		*Lat=NewLat;
	}

	return result;
}
